pub fn validate_report(shapes: &Loaded, data: &Graph) -> ValidationReportExpand description
Validate data against the shapes in shapes, producing a W3C report.
pub fn validate_report(shapes: &Loaded, data: &Graph) -> ValidationReportValidate data against the shapes in shapes, producing a W3C report.