pub fn validate_graphs(
data: &Graph,
shapes: &Graph,
schema: &Schema,
) -> Result<ValidationOutcome, NonStratifiable>Expand description
Validate split data and shapes graphs using the selected graph mode.
pub fn validate_graphs(
data: &Graph,
shapes: &Graph,
schema: &Schema,
) -> Result<ValidationOutcome, NonStratifiable>Validate split data and shapes graphs using the selected graph mode.