pub fn validate_plan_with_context(
data: &Graph,
context: &Graph,
plan: &PhysicalPlan,
) -> Result<ValidationOutcome, NonStratifiable>Expand description
Validate plan focus nodes from data against the supplied execution context.
pub fn validate_plan_with_context(
data: &Graph,
context: &Graph,
plan: &PhysicalPlan,
) -> Result<ValidationOutcome, NonStratifiable>Validate plan focus nodes from data against the supplied execution context.