pub struct ValidationOutcome {
pub conforms: bool,
pub violations: Vec<Violation>,
}Expand description
The outcome of validating a data graph against a schema.
Fields
conforms: boolviolations: Vec<Violation>Trait Implementations
Sourceimpl Clone for ValidationOutcome
impl Clone for ValidationOutcome
Sourcefn clone(&self) -> ValidationOutcome
fn clone(&self) -> ValidationOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationOutcome
impl Debug for ValidationOutcome
Sourceimpl<'de> Deserialize<'de> for ValidationOutcome
impl<'de> Deserialize<'de> for ValidationOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ValidationOutcome
Sourceimpl PartialEq for ValidationOutcome
impl PartialEq for ValidationOutcome
Sourcefn eq(&self, other: &ValidationOutcome) -> bool
fn eq(&self, other: &ValidationOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ValidationOutcome
impl Serialize for ValidationOutcome
impl StructuralPartialEq for ValidationOutcome