graph_union

Function graph_union 

pub fn graph_union(left: &Graph, right: &Graph) -> Graph
The RDF merge of two graphs (left ∪ right). The standard way to build the context graph the *_with_context repair entry points expect: the union of a data graph and a shapes/ontology graph.